from .aws_product_api import AwsProductApi
import traceback

class StylensCrawler(object):
  def __init__(self, generate_item_searches=False):
    self._aws = AwsProductApi(generate_item_searches=generate_item_searches)

  def get_item_searches(self):
    return self._aws.get_item_searches()

  def get_items(self, item_searches):
    item_list = self._aws.item_search(item_searches)
    try:
      for items in item_list:
        for item in items:
          yield item
    except Exception as e:
      print(e)
      traceback.print_exc(limit=None)
      yield None

  def get_similar_items(self):
    item_list = self._aws.item_lookups()
    try:
      for items in item_list:
        for item in items:
          yield item
    except Exception as e:
      print(e)
      traceback.print_exc(limit=None)
      yield None





# coding: utf-8

from __future__ import absolute_import
from .base_model_ import Model
from datetime import date, datetime
from typing import List, Dict
from ..util import deserialize_model


class ItemPrice(Model):
  def __init__(self,
               amount=None,
               currency_code=None,
               formatted_price=None):
    self.bl_types = {
      'amount': str,
      'currency_code': str,
      'formatted_price': str
    }

    self.attribute_map = {
      'amount': 'amount',
      'currency_code': 'currency_code',
      'formatted_price': 'formatted_price'
    }

    self._amount = amount
    self._currency_code = currency_code
    self._formatted_price = formatted_price

  @classmethod
  def from_dict(cls, dikt) -> 'ItemPrice':
    return deserialize_model(dikt, cls)

  @property
  def amount(self) -> str:
    return self._amount

  @amount.setter
  def amount(self, amount: str):
    self._amount = amount

  @property
  def currency_code(self) -> str:
    return self._currency_code

  @currency_code.setter
  def currency_code(self, currency_code: str):
    self._currency_code = currency_code

  @property
  def formatted_price(self) -> str:
    return self._formatted_price

  @formatted_price.setter
  def formatted_price(self, formatted_price : str):
    self._formatted_price = formatted_price



# coding: utf-8

"""
    stylelens-crawl-amazon

    Contact: master@bluehack.net
"""


import sys
from setuptools import setup, find_packages

NAME = "stylelens-crawl-amazon"
VERSION = "0.0.21"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["pymongo","bottlenose","bs4"]

setup(
    name=NAME,
    version=VERSION,
    description="stylelens-crawl-amazon",
    author_email="master@bluehack.net",
    url="",
    keywords=["BlueLens", "stylelens-crawl-amazon"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    """
)
